@@ -23,10 +23,9 @@ class Association(Transaction):
         if self.expires != 0 and self.expires <= current:
             raise Exception('Wring exipration date')
 
-    def __to_binary_V1(self):
+    def __to_binary_v1(self):
         if self.anchor:
-            return (
-                b'\x10' +
+            return (b'\x10' +
                 b'\1' +
                 crypto.str2bytes(self.chain_id) +
                 base58.b58decode(self.sender_public_key) +
@@ -38,8 +37,7 @@ class Association(Transaction):
                 struct.pack(">Q", self.timestamp) +
                 struct.pack(">Q", self.tx_fee))
         else:
-            return (
-                    b'\x10' +
+            return (b'\x10' +
                     b'\1' +
                     crypto.str2bytes(self.chain_id) +
                     base58.b58decode(self.sender_public_key) +
@@ -50,7 +48,7 @@ class Association(Transaction):
                     struct.pack(">Q", self.tx_fee))
 
 
-    def __to_binary_V3(self):
+    def __to_binary_v3(self):
         return (self.TYPE.to_bytes(1, 'big') +
                 b'\3' +
                 crypto.str2bytes(self.chain_id) +
@@ -66,9 +64,9 @@ class Association(Transaction):
 
     def to_binary(self):
         if self.version == 1:
-            return self.__to_binary_V1()
+            return self.__to_binary_v1()
         elif self.version == 3:
-            return self.__to_binary_V3()
+            return self.__to_binary_v3()
         else:
             raise Exception('Incorrect Version')
 
@@ -76,6 +74,7 @@ class Association(Transaction):
 
     def to_json(self):
         tx = {
+                "id": self.id if self.id else "",
                 "type": self.TYPE,
                 "version": self.version,
                 "sender": self.sender,
@@ -87,7 +86,8 @@ class Association(Transaction):
                 "timestamp": self.timestamp,
                 "expires": self.expires if self.version != 1 else None,
                 "fee": self.tx_fee,
-                "proofs": self.proofs
+                "proofs": self.proofs,
+                "height": self.height if self.height else ""
             }
         if self.version == 1:
             tx.pop('expires')
@@ -112,5 +112,11 @@ class Association(Transaction):
         tx.proofs = data['proofs'] if 'proofs' in data else []
         tx.height = data['height'] if 'height' in data else ''
 
+        if "sponsor_public_key" in data:
+            tx.sponsor = data['sponsor']
+            tx.sponsor_public_key = data['sponsorPublicKey']
+            tx.sponsor_key_type = data['sponsorKeyType']
+
+
         return tx
 
