@@ -65,6 +65,7 @@ class RevokeAssociation(Transaction):
 
     def to_json(self):
         return (crypto.merge_dicts({
+            "id": self.id if self.id else "",
             "type": self.TYPE,
             "version": self.version,
             "sender": self.sender_public_key,
@@ -75,7 +76,8 @@ class RevokeAssociation(Transaction):
             "hash": base58.b58encode(crypto.str2bytes(self.anchor)),
             "timestamp": self.timestamp,
             "fee": self.tx_fee,
-            "proofs": self.proofs
+            "proofs": self.proofs,
+            "height": self.height if self.height else ""
         }, self._sponsor_json()))
 
     @staticmethod
